@@ -5,7 +5,7 @@ use warnings;
 
 use syntax 'maybe';
 
-our $VERSION = 'v0.0.3';
+our $VERSION = 'v0.0.4';
 
 use Moo;
 use Types::Standard qw/Maybe Object Str is_Str/;
@@ -75,14 +75,14 @@ our $AUTOLOAD; # keep 'use strict' happy
 sub AUTOLOAD {
     my $self = shift;
     
-    my $method_call = do { $_ = $AUTOLOAD; s/.*:://; $_ };
-    my $db_statement = uc($method_call);
-    my $peer_address = $self->_peer_address( );
+    my $method_call    = do { $_ = $AUTOLOAD; s/.*:://; $_ };
+    my $db_statement   = uc($method_call);
+    my $operation_name = $self->_operation_name( $method_call );
+    my $peer_address   = $self->_peer_address( );
     
-    # minimize scope and duration of the wrapped method
-    do {
+    my $method_wrap = sub {
         OpenTracing::AutoScope->start_guarded_span(
-            $self->_operation_name( $method_call ),
+            $operation_name,
             tags => {
                 'component'     => __PACKAGE__,
                 'db.statement'  => $db_statement,
@@ -94,8 +94,13 @@ sub AUTOLOAD {
         );
         
         return $self->redis->$method_call(@_);
-    }
+    };
     
+    # Save this method for future calls
+    no strict 'refs';
+    *$AUTOLOAD = $method_wrap;
+    
+    goto $method_wrap;
 }
 
 
